
package org.mule.module.netsuite.config;

import java.util.List;
import org.apache.commons.lang.StringUtils;
import org.mule.config.spring.MuleHierarchicalBeanDefinitionParserDelegate;
import org.mule.config.spring.util.SpringXMLUtils;
import org.mule.module.netsuite.processors.AttachRecordMessageProcessor;
import org.mule.util.TemplateParser;
import org.springframework.beans.MutablePropertyValues;
import org.springframework.beans.PropertyValue;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.beans.factory.support.BeanDefinitionBuilder;
import org.springframework.beans.factory.support.ManagedList;
import org.springframework.beans.factory.xml.BeanDefinitionParser;
import org.springframework.beans.factory.xml.ParserContext;
import org.w3c.dom.Element;

public class AttachRecordDefinitionParser
    implements BeanDefinitionParser
{

    /**
     * Mule Pattern Info
     * 
     */
    private TemplateParser.PatternInfo patternInfo;

    public AttachRecordDefinitionParser() {
        patternInfo = TemplateParser.createMuleStyleParser().getStyle();
    }

    public BeanDefinition parse(Element element, ParserContext parserContent) {
        BeanDefinitionBuilder builder = BeanDefinitionBuilder.rootBeanDefinition(AttachRecordMessageProcessor.class.getName());
        String configRef = element.getAttribute("config-ref");
        if ((configRef!= null)&&(!StringUtils.isBlank(configRef))) {
            builder.addPropertyValue("moduleObject", configRef);
        }
        if (element.hasAttribute("sourceRecordType")) {
            builder.addPropertyValue("sourceRecordType", element.getAttribute("sourceRecordType"));
        }
        if ((element.getAttribute("sourceId")!= null)&&(!StringUtils.isBlank(element.getAttribute("sourceId")))) {
            builder.addPropertyValue("sourceId", element.getAttribute("sourceId"));
        }
        if (element.hasAttribute("sourceIdType")) {
            builder.addPropertyValue("sourceIdType", element.getAttribute("sourceIdType"));
        }
        if (element.hasAttribute("destinationRecordType")) {
            builder.addPropertyValue("destinationRecordType", element.getAttribute("destinationRecordType"));
        }
        if ((element.getAttribute("destinationId")!= null)&&(!StringUtils.isBlank(element.getAttribute("destinationId")))) {
            builder.addPropertyValue("destinationId", element.getAttribute("destinationId"));
        }
        if (element.hasAttribute("destinationIdType")) {
            builder.addPropertyValue("destinationIdType", element.getAttribute("destinationIdType"));
        }
        if (element.hasAttribute("contanctRecordType")) {
            builder.addPropertyValue("contanctRecordType", element.getAttribute("contanctRecordType"));
        }
        if ((element.getAttribute("contanctId")!= null)&&(!StringUtils.isBlank(element.getAttribute("contanctId")))) {
            builder.addPropertyValue("contanctId", element.getAttribute("contanctId"));
        }
        if (element.hasAttribute("contanctIdType")) {
            builder.addPropertyValue("contanctIdType", element.getAttribute("contanctIdType"));
        }
        BeanDefinition definition = builder.getBeanDefinition();
        definition.setAttribute(MuleHierarchicalBeanDefinitionParserDelegate.MULE_NO_RECURSE, Boolean.TRUE);
        MutablePropertyValues propertyValues = parserContent.getContainingBeanDefinition().getPropertyValues();
        if (parserContent.getContainingBeanDefinition().getBeanClassName().equals("org.mule.config.spring.factories.PollingMessageSourceFactoryBean")) {
            propertyValues.addPropertyValue("messageProcessor", definition);
        } else {
            if (parserContent.getContainingBeanDefinition().getBeanClassName().equals("org.mule.enricher.MessageEnricher")) {
                propertyValues.addPropertyValue("enrichmentMessageProcessor", definition);
            } else {
                PropertyValue messageProcessors = propertyValues.getPropertyValue("messageProcessors");
                if ((messageProcessors == null)||(messageProcessors.getValue() == null)) {
                    propertyValues.addPropertyValue("messageProcessors", new ManagedList());
                }
                List listMessageProcessors = ((List) propertyValues.getPropertyValue("messageProcessors").getValue());
                listMessageProcessors.add(definition);
            }
        }
        return definition;
    }

    protected String getAttributeValue(Element element, String attributeName) {
        if (!StringUtils.isEmpty(element.getAttribute(attributeName))) {
            return element.getAttribute(attributeName);
        }
        return null;
    }

    private String generateChildBeanName(Element element) {
        String id = SpringXMLUtils.getNameOrId(element);
        if (StringUtils.isBlank(id)) {
            String parentId = SpringXMLUtils.getNameOrId(((Element) element.getParentNode()));
            return ((("."+ parentId)+":")+ element.getLocalName());
        } else {
            return id;
        }
    }

}
